@@ -493,6 +493,10 @@ class Screen(object):
     self.screen[self.height - 1][self.width - 1] = '\''    
 
   def printAt(self, text, x, y, color = None, bgcolor = None):
+    if color is None:
+        color = Colour.white
+    if bgcolor is None:
+        bgcolor = Colour.grey
     x = int(x)
     y = int(y)
     for dx, ch in enumerate(text):
